/*
 * Copyright (C) 2010 Paul Watts (paulcwatts@gmail.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.joulespersecond.oba.elements;

/**
 * Interface defining a Route element.
 * {@link http://code.google.com/p/onebusaway/wiki/OneBusAwayRestApi_RouteElementV2}
 *
 * @author Paul Watts (paulcwatts@gmail.com)
 */
public interface ObaRoute extends ObaElement {
    public static final int TYPE_TRAM = 0;
    public static final int TYPE_SUBWAY = 1;
    public static final int TYPE_RAIL = 2;
    public static final int TYPE_BUS = 3;
    public static final int TYPE_FERRY = 4;
    public static final int TYPE_CABLECAR = 5;
    public static final int TYPE_GONDOLA = 6;
    public static final int TYPE_FUNICULAR = 7; // You can't spell "funicular" without "fun"!

    /**
     * Returns the short name of the route (ex. "10", "30").
     *
     * @return The short name of the route.
     */
    public String getShortName();

    /**
     * Returns the long name of the route (ex. "Sandpoint/QueenAnne")
     *
     * @return The long name of the route.
     */
    public String getLongName();

    /**
     * Returns the description of the route.
     *
     */
    public String getDescription();

    /**
     * @return The type of route
     */
    public int getType();

    /**
     * Returns the Url to the route schedule.
     * @return The url to the route schedule.
     */
    public String getUrl();

    /**
     * @return The route color.
     */
    public int getColor();

    /**
     * @return The route text color
     */
    public int getTextColor();

    /**
     * @return The ID of the agency operating this route.
     */
    public String getAgencyId();
}
